==> core-0.9.128-sources.jar: de/quantummaid/httpmaid/websockets/processors/PutWebsocketInRegistryProcessor.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.websockets.processors;

import de.quantummaid.httpmaid.chains.MetaData;
import de.quantummaid.httpmaid.chains.Processor;
import de.quantummaid.httpmaid.websockets.registry.ConnectionInformation;
import de.quantummaid.httpmaid.websockets.registry.WebsocketRegistry;
import de.quantummaid.httpmaid.websockets.registry.WebsocketRegistryEntry;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import lombok.extern.slf4j.Slf4j;

import static de.quantummaid.httpmaid.websockets.WebsocketMetaDataKeys.*;

@Slf4j
@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class PutWebsocketInRegistryProcessor implements Processor {

    public static Processor putWebsocketInRegistryProcessor() {
        return new PutWebsocketInRegistryProcessor();
    }

    @Override
    public void apply(final MetaData metaData) {
        final ConnectionInformation connectionInformation = metaData.get(WEBSOCKET_CONNECTION_INFORMATION);
        final WebsocketRegistryEntry dummyEntry = metaData.get(WEBSOCKET_REGISTRY_ENTRY);
        final WebsocketRegistryEntry entry = dummyEntry.fixConnectionInformation(connectionInformation);
        final WebsocketRegistry websocketRegistry = metaData.get(WEBSOCKET_REGISTRY);
        log.debug("adding websocket to registry");
        websocketRegistry.addConnection(entry);
    }
}

==> core-0.9.141-sources.jar: de/quantummaid/httpmaid/websockets/processors/PutWebsocketInRegistryProcessor.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.websockets.processors;

import de.quantummaid.httpmaid.chains.MetaData;
import de.quantummaid.httpmaid.chains.Processor;
import de.quantummaid.httpmaid.websockets.registry.ConnectionInformation;
import de.quantummaid.httpmaid.websockets.registry.WebsocketRegistry;
import de.quantummaid.httpmaid.websockets.registry.WebsocketRegistryEntry;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import lombok.extern.slf4j.Slf4j;

import static de.quantummaid.httpmaid.websockets.WebsocketMetaDataKeys.*;

@Slf4j
@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class PutWebsocketInRegistryProcessor implements Processor {

    public static Processor putWebsocketInRegistryProcessor() {
        return new PutWebsocketInRegistryProcessor();
    }

    @Override
    public void apply(final MetaData metaData) {
        final ConnectionInformation connectionInformation = metaData.get(WEBSOCKET_CONNECTION_INFORMATION);
        final WebsocketRegistryEntry dummyEntry = metaData.get(WEBSOCKET_REGISTRY_ENTRY);
        final WebsocketRegistryEntry entry = dummyEntry.fixConnectionInformation(connectionInformation);
        final WebsocketRegistry websocketRegistry = metaData.get(WEBSOCKET_REGISTRY).get();
        log.debug("adding websocket to registry");
        websocketRegistry.addConnection(entry);
    }
}
